import { Controller, Get, UseInterceptors } from '@nestjs/common'
import { UsersService } from './users.service'
import { ApiOperation, ApiTags } from '@nestjs/swagger'
import { User } from 'src/common/decorators/user.decorator'
import { NeedAuth } from 'src/common/decorators/need-auth.decorator'
import { PasswordInterceptor } from 'src/common/interceptors/password.interceptor'
import { PrismaService } from 'nestjs-prisma'
import { UserEntity } from './entities/user.entity'

@ApiTags('User')
@Controller('api/users')
export class UsersController {
  constructor(
    private readonly userService: UsersService,
    private readonly prismaService: PrismaService,
  ) {}

  @ApiOperation({ summary: '获取用户信息' })
  @UseInterceptors(PasswordInterceptor)
  @NeedAuth()
  @Get('me')
  async getUserInfo(@User('userId') userId: string): Promise<UserEntity> {
    return this.prismaService.user.findUniqueOrThrow({ where: { id: userId } })
  }
}
